The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {MatchAlign}


Title: Parsing GFA and GAF Alignment Files
Version: 0.1.2
Maintainer: Camille R. Mazurek <camillemazurek23@gmail.com>
Description: Provides tools for extracting segment paths from Graphical Fragment Assembly ('GFA') and Graph Alignment Format ('GAF') files. parse_paths_gfa() reads P (path) and W (walk) records and returns a named list of segment identifiers for each accession. parse_paths_gaf() parses the path string from each alignment and returns a named list of segments traversed by each query. parse_segment_lengths_gfa() reads S records and returns a named list of segment lengths keyed by segment identifier. These tools are intended to simplify downstream interpretation and analysis of pangenome graphs.
License: MIT + file LICENSE
Encoding: UTF-8
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
URL: https://github.com/cromazurek/MatchAlign
BugReports: https://github.com/cromazurek/MatchAlign/issues
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-09-03 21:10:48 UTC; camillemazurek2025
Author: Camille R. Mazurek [aut, cre], Michael J. Tisza [ctb]
Repository: CRAN
Date/Publication: 2026-09-12 15:00:12 UTC

Create a list where each alignment is an element with an associated list of the segments used

Description

Create a list where each alignment is an element with an associated list of the segments used

Usage

parse_paths_gaf(gaf_file)

Arguments

gaf_file

A gaf file

Value

A list where each alignment is an element with an associated list of segments used

Examples

example_gaf <- system.file("extdata", "example.gaf", package = "MatchAlign")
alignment_paths <- parse_paths_gaf(example_gaf)

Create a list where each accession is an element with an associated list of the segments

Description

Create a list where each accession is an element with an associated list of the segments

Usage

parse_paths_gfa(gfa_file)

Arguments

gfa_file

A gfa file

Value

A list where each accession is an element with an associated list of segments

Examples

example_gfa <- system.file("extdata", "example.gfa", package = "MatchAlign")
accession_paths <- parse_paths_gfa(example_gfa)

Create a list of segment lengths from a GFA file

Description

Create a list of segment lengths from a GFA file

Usage

parse_segment_lengths_gfa(gfa_file)

Arguments

gfa_file

A gfa file

Value

A named list where each segment is an element with its length

Examples

example_gfa <- system.file("extdata", "example.gfa", package = "MatchAlign")
segment_lengths <- parse_segment_lengths_gfa(example_gfa)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.